@@ -39,6 +39,10 @@ class Tier(object):
         default=None, help="Deploy module to %s" %(self.tier))
     deploy_parser.add_argument("-r", "--no-rolling", dest="rolling", 
         default=True, action = "store_false", help="Do rolling deploy to %s" %(self.tier))
+    deploy_parser.add_argument("-t", "--stop-djs-at-start", dest="stopdjs", 
+        default=False, action = "store_true", help="At start of rolling deploy stop djs on current nodes")
+    deploy_parser.add_argument("-c", "--run-common-stuff-recipe", dest="commstuff", 
+        default=False, action = "store_true", help="Run common stuff at start of deploy")
     deploy_parser.add_argument("-d", "--no-djrestart", dest="djrestart", 
         default=True, action = "store_false", help="Dj Restart reqd: %s" %(self.tier))
     deploy_parser.add_argument("-s", "--srcpath", dest="src_path", 
@@ -50,6 +54,10 @@ class Tier(object):
     base_path = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
     if self.tier == "web":
       deploy_cmd.extend([base_path + "/../scripts/chef_deploy_web.sh", "-e", args.environment])
+      if args.commstuff == True:
+        deploy_cmd.extend(["-c"])
+      if args.stopdjs == True:
+        deploy_cmd.extend(["-t"])
       if args.rolling == False:
         deploy_cmd.extend(["-r"])
       if args.djrestart == False:
